Skip to content

Add a label to a thread for a Messenger page

Version

20.0.021.0.022.0.023.0.024.0.025.0.026.0.0

Copy for LLM

View as Markdown

Download OpenAPI spec

Associate and remove labels for a Messenger page thread.

Base URL

| | | | https://graph.facebook.com/v26.0 |

Endpoints

| | | | POST | /{thread_label_id}/label | | DELETE | /{thread_label_id}/label |


POST /{thread_label_id}/label

Request Syntax

POST /{thread_label_id}/label

Try it

Select language

cURLJavaScriptPython


curl --request POST \  
  --url 'https://graph.facebook.com/v26.0/{thread_label_id}/label' \  
  --header 'Authorization: Bearer <Token>' \  
  --header 'Content-Type: application/json' \  
  --data '{}'

Path Parameters


thread_label_idstring·required

Thread label ID

Request BodyRequired


Content Type: application/json

Schema: PageUserMessageThreadLabelLabelRequest

Show child attributes


PageUserMessageThreadLabelLabelRequest


userstring·required

The PSID of the user to associate with the thread label

Responses


200

Response indicating whether the thread label was associated

Content Type: application/json

Schema: PageUserMessageThreadLabelLabelResponse

Show child attributes


PageUserMessageThreadLabelLabelResponse


successboolean·required

Indicates whether the operation was successful

400

Bad request

Content Type: application/json

Schema: StandardError

Show child attributes


StandardError


messagestring·required


typestring


codeinteger·required


error_subcodeinteger


is_transientboolean


error_data{}


error_user_msgstring


error_user_titlestring


fbtrace_idstring

403

Forbidden

Content Type: application/json

Schema: StandardError

Show child attributes


StandardError


messagestring·required


typestring


codeinteger·required


error_subcodeinteger


is_transientboolean


error_data{}


error_user_msgstring


error_user_titlestring


fbtrace_idstring

Select language

cURLJavaScriptPython


curl --request POST \  
  --url 'https://graph.facebook.com/v26.0/{thread_label_id}/label' \  
  --header 'Authorization: Bearer <Token>' \  
  --header 'Content-Type: application/json' \  
  --data '{}'

DELETE /{thread_label_id}/label

Request Syntax

DELETE /{thread_label_id}/label

Try it

Select language

cURLJavaScriptPython


curl --request DELETE \  
  --url 'https://graph.facebook.com/v26.0/{thread_label_id}/label' \  
  --header 'Authorization: Bearer <Token>' \  
  --header 'Content-Type: application/json' \  
  --data '{}'

Path Parameters


thread_label_idstring·required

Thread label ID

Query Parameters


userstring·required

The PSID of the user to remove from the thread label

Responses


200

Response indicating whether the thread label was removed

Content Type: application/json

Schema: PageUserMessageThreadLabelLabelResponse

Show child attributes


PageUserMessageThreadLabelLabelResponse


successboolean·required

Indicates whether the operation was successful

400

Bad request

Content Type: application/json

Schema: StandardError

Show child attributes


StandardError


messagestring·required


typestring


codeinteger·required


error_subcodeinteger


is_transientboolean


error_data{}


error_user_msgstring


error_user_titlestring


fbtrace_idstring

403

Forbidden

Content Type: application/json

Schema: StandardError

Show child attributes


StandardError


messagestring·required


typestring


codeinteger·required


error_subcodeinteger


is_transientboolean


error_data{}


error_user_msgstring


error_user_titlestring


fbtrace_idstring

Select language

cURLJavaScriptPython


curl --request DELETE \  
  --url 'https://graph.facebook.com/v26.0/{thread_label_id}/label' \  
  --header 'Authorization: Bearer <Token>' \  
  --header 'Content-Type: application/json' \  
  --data '{}'

Authentication

| | | | Scheme | Type | Location | | OAuthToken__access_token | API Key | Query: access_token | | OAuthToken__oauth_token | API Key | Query: oauth_token | | OAuthToken__Authorization | HTTP Bearer | Header: Authorization |

Usage Examples

OAuthToken__access_token:

Include access_token=your-api-key-here in query parameters

OAuthToken__oauth_token:

Include oauth_token=your-api-key-here in query parameters

OAuthToken__Authorization:

Include Authorization: Bearer your-token-here in request headers

Global Authentication Requirements

All endpoints require:

OAuthToken__access_token AND OAuthToken__oauth_token AND OAuthToken__Authorization

Unofficial mirror for reference/search purposes. All content originates from developers.facebook.com — see the source link at the top of each page. Machine-readable indexes: llms.txt · llms-full.txt · About