Skip to content

Page Messaging Feature Review

Version

20.0.021.0.022.0.023.0.024.0.025.0.026.0.0

Copy for LLM

View as Markdown

Download OpenAPI spec

Retrieve the messaging features that are available to a page through feature review.

Base URL

| | | | https://graph.facebook.com/v26.0 |

Endpoints

| | | | GET | /{page_id}/messaging_feature_review |


GET /{page_id}/messaging_feature_review

Request Syntax

GET /{page_id}/messaging_feature_review

Try it

Select language

cURLJavaScriptPython


curl --request GET \  
  --url 'https://graph.facebook.com/v26.0/{page_id}/messaging_feature_review' \  
  --header 'Authorization: Bearer <Token>' \  
  --header 'Content-Type: application/json' \  
  --data '{}'

Path Parameters


page_idstring·required

The page ID to retrieve messaging feature review status for

Query Parameters


fieldsstring

Fields selected for return, separated by comma. More details in section 'Fields'(https://developers.facebook.com/docs/graph-api/overview). Note only field selection (with nesting) is supported, but not all the features of Field Expansion(https://developers.facebook.com/docs/graph-api/guides/field-expansion/), e.g. limit, offset, etc.

Responses


200

List of messaging features and their review statuses for the page

Content Type: application/json

Schema: PageMessagingFeatureReviewResponse

Show child attributes


PageMessagingFeatureReviewResponse


dataarray of PageMessagingFeatureReviewItem·required

List of messaging features and their review statuses for the page

Show child attributes


data[]PageMessagingFeatureReviewItem

Show child attributes


featurestring·required

The name of the messaging feature


statusOne of "approved", "pending", "limited", "rejected"·required

The review status of the feature (approved, pending, limited, or rejected)

400

Bad request

Content Type: application/json

Schema: StandardError

Show child attributes


StandardError


messagestring·required


typestring


codeinteger·required


error_subcodeinteger


is_transientboolean


error_data{}


error_user_msgstring


error_user_titlestring


fbtrace_idstring

403

Forbidden

Content Type: application/json

Schema: StandardError

Show child attributes


StandardError


messagestring·required


typestring


codeinteger·required


error_subcodeinteger


is_transientboolean


error_data{}


error_user_msgstring


error_user_titlestring


fbtrace_idstring

Select language

cURLJavaScriptPython


curl --request GET \  
  --url 'https://graph.facebook.com/v26.0/{page_id}/messaging_feature_review' \  
  --header 'Authorization: Bearer <Token>' \  
  --header 'Content-Type: application/json' \  
  --data '{}'

Authentication

| | | | Scheme | Type | Location | | OAuthToken__access_token | API Key | Query: access_token | | OAuthToken__oauth_token | API Key | Query: oauth_token | | OAuthToken__Authorization | HTTP Bearer | Header: Authorization |

Usage Examples

OAuthToken__access_token:

Include access_token=your-api-key-here in query parameters

OAuthToken__oauth_token:

Include oauth_token=your-api-key-here in query parameters

OAuthToken__Authorization:

Include Authorization: Bearer your-token-here in request headers

Global Authentication Requirements

All endpoints require:

OAuthToken__access_token AND OAuthToken__oauth_token AND OAuthToken__Authorization

Unofficial mirror for reference/search purposes. All content originates from developers.facebook.com — see the source link at the top of each page. Machine-readable indexes: llms.txt · llms-full.txt · About