Skip to content

Page Status API

Version

20.0.021.0.022.0.023.0.024.0.025.0.026.0.0

Copy for LLM

View as Markdown

Download OpenAPI spec

Fetch integrity and business messaging status information for a Facebook Page.

Base URL

| | | | https://graph.facebook.com/v26.0 |

Endpoints

| | | | GET | /{page_id}/page_status |


GET /{page_id}/page_status

Request Syntax

GET /{page_id}/page_status

Try it

Select language

cURLJavaScriptPython


curl --request GET \  
  --url 'https://graph.facebook.com/v26.0/{page_id}/page_status' \  
  --header 'Authorization: Bearer <Token>' \  
  --header 'Content-Type: application/json' \  
  --data '{}'

Path Parameters


page_idstring·required

The page ID for the call status API

Responses


200

Integrity and business messaging status for the page

Content Type: application/json

Schema: PageStatusResponse

Show child attributes


PageStatusResponse


idstring·required

Page ID


timestampinteger·required

The time when this response was generated


statusOne of "warning", "restricted", "ok", "suspended"·required

The overall status of the page


violationsarray of PageStatusViolation

The violations that are affecting the page status

Show child attributes


violations[]PageStatusViolation

Show child attributes


typestring·required

The type of this violation. Usually, this is linked to the action that triggered the violation.


descriptionstring·required

Static string description


urlstring·required

URL to the help page for this violation


severityOne of "LOW", "MEDIUM", "HIGH"

The severity of this violation


restrictionsarray of PageStatusRestriction

The restrictions that are affecting the page status

Show child attributes


restrictions[]PageStatusRestriction

Show child attributes


featureOne of "page_create_group", "page_edit_category", "page_invite", "page_merge", "page_messaging", "page_messaging_api", "page_name_change", "page_online_event", "page_publish", "post_media", "unknown"·required

The features restricted as a result of some violation


descriptionstring·required

A human-readable description of the feature limit


applied_timeinteger·required

The time when this restriction was applied


expiration_timeinteger

The time when this restriction will expire


violation_typearray of string

The violation type that triggered this restriction

Show child attributes


violation_type[]string


recommended_actionsarray of PageStatusRecommendedAction

The recommended actions that can be taken to improve the page status

Show child attributes


recommended_actions[]PageStatusRecommendedAction

Show child attributes


typeOne of "LEARN_MORE", "FILE_APPEAL", "SUPPORT_TICKET"·required

The type of recommended action, e.g. FILE_APPEAL, LEARN_MORE, etc.


urlstring·required

The action URL for this recommended action.


violation_typearray of string·required

The violation type that triggered this recommended action.

Show child attributes


violation_type[]string


action_eventsarray of PageStatusActionEvent

The statuses of the recommended actions that have been taken

Show child attributes


action_events[]PageStatusActionEvent

Show child attributes


typeOne of "LEARN_MORE", "FILE_APPEAL", "SUPPORT_TICKET"·required

The type of recommended action, e.g. FILE_APPEAL, LEARN_MORE, etc.


statusOne of "OPEN", "PENDING", "CLOSED"·required

The status of this recommended action, e.g. PENDING, COMPLETED, etc.


created_timeinteger·required

The time when this recommended action was created


updated_timeinteger·required

The time when this recommended action was updated


violation_typearray of string

The violation type that triggered this recommended action.

Show child attributes


violation_type[]string

Select language

cURLJavaScriptPython


curl --request GET \  
  --url 'https://graph.facebook.com/v26.0/{page_id}/page_status' \  
  --header 'Authorization: Bearer <Token>' \  
  --header 'Content-Type: application/json' \  
  --data '{}'

Authentication

| | | | Scheme | Type | Location | | OAuthToken__access_token | API Key | Query: access_token | | OAuthToken__oauth_token | API Key | Query: oauth_token | | OAuthToken__Authorization | HTTP Bearer | Header: Authorization |

Usage Examples

OAuthToken__access_token:

Include access_token=your-api-key-here in query parameters

OAuthToken__oauth_token:

Include oauth_token=your-api-key-here in query parameters

OAuthToken__Authorization:

Include Authorization: Bearer your-token-here in request headers

Global Authentication Requirements

All endpoints require:

OAuthToken__access_token AND OAuthToken__oauth_token AND OAuthToken__Authorization

Unofficial mirror for reference/search purposes. All content originates from developers.facebook.com — see the source link at the top of each page. Machine-readable indexes: llms.txt · llms-full.txt · About