Skip to content

Retrieve a Messenger bot persona

Version

20.0.021.0.022.0.023.0.024.0.025.0.026.0.0

Copy for LLM

View as Markdown

Download OpenAPI spec

Retrieve and delete a Messenger bot persona by ID.

Base URL

| | | | https://graph.facebook.com/v26.0 |

Endpoints

| | | | GET | /{persona_id} | | DELETE | /{persona_id} |


GET /{persona_id}

Request Syntax

GET /{persona_id}

Try it

Select language

cURLJavaScriptPython


curl --request GET \  
  --url 'https://graph.facebook.com/v26.0/{persona_id}' \  
  --header 'Authorization: Bearer <Token>' \  
  --header 'Content-Type: application/json' \  
  --data '{}'

Path Parameters


persona_idstring·required

Messenger Platform Persona ID

Query Parameters


fieldsstring

Fields selected for return, separated by comma. More details in section 'Fields'(https://developers.facebook.com/docs/graph-api/overview). Note only field selection (with nesting) is supported, but not all the features of Field Expansion(https://developers.facebook.com/docs/graph-api/guides/field-expansion/), e.g. limit, offset, etc.

Responses


200

Details of a Messenger bot persona

Content Type: application/json

Schema: PersonaResponse

Show child attributes


PersonaResponse


idstring·required

The ID of the persona


namestring

The display name of the persona


profile_picture_urlstring

The URL of the persona profile picture

400

Bad request

Content Type: application/json

Schema: StandardError

Show child attributes


StandardError


messagestring·required


typestring


codeinteger·required


error_subcodeinteger


is_transientboolean


error_data{}


error_user_msgstring


error_user_titlestring


fbtrace_idstring

403

Forbidden

Content Type: application/json

Schema: StandardError

Show child attributes


StandardError


messagestring·required


typestring


codeinteger·required


error_subcodeinteger


is_transientboolean


error_data{}


error_user_msgstring


error_user_titlestring


fbtrace_idstring

Select language

cURLJavaScriptPython


curl --request GET \  
  --url 'https://graph.facebook.com/v26.0/{persona_id}' \  
  --header 'Authorization: Bearer <Token>' \  
  --header 'Content-Type: application/json' \  
  --data '{}'

DELETE /{persona_id}

Request Syntax

DELETE /{persona_id}

Try it

Select language

cURLJavaScriptPython


curl --request DELETE \  
  --url 'https://graph.facebook.com/v26.0/{persona_id}' \  
  --header 'Authorization: Bearer <Token>' \  
  --header 'Content-Type: application/json' \  
  --data '{}'

Path Parameters


persona_idstring·required

Messenger Platform Persona ID

Responses


200

Delete a Messenger bot persona

Content Type: application/json

Schema: PersonaDeleteResponse

Show child attributes


PersonaDeleteResponse


successboolean·required

Whether the persona was successfully deleted

400

Bad request

Content Type: application/json

Schema: StandardError

Show child attributes


StandardError


messagestring·required


typestring


codeinteger·required


error_subcodeinteger


is_transientboolean


error_data{}


error_user_msgstring


error_user_titlestring


fbtrace_idstring

403

Forbidden

Content Type: application/json

Schema: StandardError

Show child attributes


StandardError


messagestring·required


typestring


codeinteger·required


error_subcodeinteger


is_transientboolean


error_data{}


error_user_msgstring


error_user_titlestring


fbtrace_idstring

Select language

cURLJavaScriptPython


curl --request DELETE \  
  --url 'https://graph.facebook.com/v26.0/{persona_id}' \  
  --header 'Authorization: Bearer <Token>' \  
  --header 'Content-Type: application/json' \  
  --data '{}'

Authentication

| | | | Scheme | Type | Location | | OAuthToken__access_token | API Key | Query: access_token | | OAuthToken__oauth_token | API Key | Query: oauth_token | | OAuthToken__Authorization | HTTP Bearer | Header: Authorization |

Usage Examples

OAuthToken__access_token:

Include access_token=your-api-key-here in query parameters

OAuthToken__oauth_token:

Include oauth_token=your-api-key-here in query parameters

OAuthToken__Authorization:

Include Authorization: Bearer your-token-here in request headers

Global Authentication Requirements

All endpoints require:

OAuthToken__access_token AND OAuthToken__oauth_token AND OAuthToken__Authorization

Unofficial mirror for reference/search purposes. All content originates from developers.facebook.com — see the source link at the top of each page. Machine-readable indexes: llms.txt · llms-full.txt · About