Appearance
Retrieve a thread label for a Messenger page
Version
20.0.021.0.022.0.023.0.024.0.025.0.026.0.0
Copy for LLM
Retrieve and delete thread labels for a Messenger page.
Base URL
| | | | https://graph.facebook.com/v26.0 |
Endpoints
| | | | GET | /{thread_label_id} | | DELETE | /{thread_label_id} |
GET /{thread_label_id}
Request Syntax
GET /{thread_label_id}
Try it
Select language
cURLJavaScriptPython
curl --request GET \
--url 'https://graph.facebook.com/v26.0/{thread_label_id}' \
--header 'Authorization: Bearer <Token>' \
--header 'Content-Type: application/json' \
--data '{}'Path Parameters
thread_label_idstring·required
Thread label ID
Query Parameters
fieldsstring
Fields selected for return, separated by comma. More details in section 'Fields'(https://developers.facebook.com/docs/graph-api/overview). Note only field selection (with nesting) is supported, but not all the features of Field Expansion(https://developers.facebook.com/docs/graph-api/guides/field-expansion/), e.g. limit, offset, etc.
Responses
200
Thread label details for a Messenger page
Content Type: application/json
Schema: PageUserMessageThreadLabelResponse
Show child attributes
PageUserMessageThreadLabelResponse
idstring·required
The ID of the thread label
page_label_namestring
The name of the thread label
400
Bad request
Content Type: application/json
Schema: StandardError
Show child attributes
StandardError
messagestring·required
typestring
codeinteger·required
error_subcodeinteger
is_transientboolean
error_data{}
error_user_msgstring
error_user_titlestring
fbtrace_idstring
403
Forbidden
Content Type: application/json
Schema: StandardError
Show child attributes
StandardError
messagestring·required
typestring
codeinteger·required
error_subcodeinteger
is_transientboolean
error_data{}
error_user_msgstring
error_user_titlestring
fbtrace_idstring
Select language
cURLJavaScriptPython
curl --request GET \
--url 'https://graph.facebook.com/v26.0/{thread_label_id}' \
--header 'Authorization: Bearer <Token>' \
--header 'Content-Type: application/json' \
--data '{}'DELETE /{thread_label_id}
Request Syntax
DELETE /{thread_label_id}
Try it
Select language
cURLJavaScriptPython
curl --request DELETE \
--url 'https://graph.facebook.com/v26.0/{thread_label_id}' \
--header 'Authorization: Bearer <Token>' \
--header 'Content-Type: application/json' \
--data '{}'Path Parameters
thread_label_idstring·required
Thread label ID
Responses
200
Response indicating success of thread label deletion
Content Type: application/json
Schema: PageUserMessageThreadLabelDeleteResponse
Show child attributes
PageUserMessageThreadLabelDeleteResponse
successboolean·required
Whether the thread label was successfully deleted
400
Bad request
Content Type: application/json
Schema: StandardError
Show child attributes
StandardError
messagestring·required
typestring
codeinteger·required
error_subcodeinteger
is_transientboolean
error_data{}
error_user_msgstring
error_user_titlestring
fbtrace_idstring
403
Forbidden
Content Type: application/json
Schema: StandardError
Show child attributes
StandardError
messagestring·required
typestring
codeinteger·required
error_subcodeinteger
is_transientboolean
error_data{}
error_user_msgstring
error_user_titlestring
fbtrace_idstring
Select language
cURLJavaScriptPython
curl --request DELETE \
--url 'https://graph.facebook.com/v26.0/{thread_label_id}' \
--header 'Authorization: Bearer <Token>' \
--header 'Content-Type: application/json' \
--data '{}'Authentication
| | | | Scheme | Type | Location | | OAuthToken__access_token | API Key | Query: access_token | | OAuthToken__oauth_token | API Key | Query: oauth_token | | OAuthToken__Authorization | HTTP Bearer | Header: Authorization |
Usage Examples
OAuthToken__access_token:
Include access_token=your-api-key-here in query parameters
OAuthToken__oauth_token:
Include oauth_token=your-api-key-here in query parameters
OAuthToken__Authorization:
Include Authorization: Bearer your-token-here in request headers
Global Authentication Requirements
All endpoints require:
OAuthToken__access_token AND OAuthToken__oauth_token AND OAuthToken__Authorization